//Source file: ConfPolicyType.java
//Date: October 2006
//Conference Call Control for 3GPP TS 29.198-04-5 V1.0.0 (Release 7)

package org.csapi.jr.se.cc.cccs;

/**
 * Defines policy type for the conference.
If undefined the gateway will select an appropriate default.
If a mono media conference policy is specified for a multi-media conference, the gateway will select appropriate defaults for the multi-media policy items.
If a multi-media policy is selected for a mono-media (voice-only) conference, the multi-media conference items will be ignored.
 *
 */
public final class ConfPolicyType implements java.io.Serializable {

    private int _value;
    private static int _size = 3;
    private static ConfPolicyType[] _array = new ConfPolicyType[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private ConfPolicyType(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Undefined
     */
    public static final int _CONFERENCE_POLICY_UNDEFINED =  0;

    /**
     * Undefined
     */
    public static final ConfPolicyType CONFERENCE_POLICY_UNDEFINED = new ConfPolicyType(_CONFERENCE_POLICY_UNDEFINED);

    /**
     * CCCS - monomedia conference policy
     */
    public static final int _CONFERENCE_POLICY_MONOMEDIA =  1;

    /**
     * CCCS - monomedia conference policy
     */
    public static final ConfPolicyType CONFERENCE_POLICY_MONOMEDIA = new ConfPolicyType(_CONFERENCE_POLICY_MONOMEDIA);

    /**
     * MMCCS - multimedia conference policy
     */
    public static final int _CONFERENCE_POLICY_MULTIMEDIA =  2;

    /**
     * MMCCS - multimedia conference policy
     */
    public static final ConfPolicyType CONFERENCE_POLICY_MULTIMEDIA = new ConfPolicyType(_CONFERENCE_POLICY_MULTIMEDIA);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved ConfPolicyType object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the ConfPolicyType object
     */
    public String getValueText() {
        switch (_value) {
            case _CONFERENCE_POLICY_UNDEFINED:
                return "CONFERENCE_POLICY_UNDEFINED";
            case _CONFERENCE_POLICY_MONOMEDIA:
                return "CONFERENCE_POLICY_MONOMEDIA";
            case _CONFERENCE_POLICY_MULTIMEDIA:
                return "CONFERENCE_POLICY_MULTIMEDIA";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 2
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static ConfPolicyType getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof ConfPolicyType)) {
            return false;
        }
        ConfPolicyType confPolicyType = (ConfPolicyType) o; 
        if(!(this.getValue() == confPolicyType.getValue())) {
            return false;
        }
        if (this.hashCode() != confPolicyType.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // ConfPolicyType

