//Source file: MonoMediaConfPolicy.java
//Date: October 2006
//Conference Call Control for 3GPP TS 29.198-04-5 V1.0.0 (Release 7)

package org.csapi.jr.se.cc.cccs;

/**
 * Defines the type of conference policy as a sequence of Policy Items and their values. 
For mono media there are only two types of conference policies; specified, that is the application provides the policy, or undefined, that is the GW may choose a default conference policy. 
 * 
 */
public final class MonoMediaConfPolicy implements java.io.Serializable {

    private boolean joinAllowed;

    /**
     * Creates a new MonoMediaConfPolicy instance.
     */
    public MonoMediaConfPolicy () {}

    /**
     * Creates a new MonoMediaConfPolicy instance.
     * @param _joinAllowed   Specifies if dial-in to the conference is allowed. Parties can dial-in to the conference using the address returned during reservation. If this is specified the application will receive partyJoined for each participant dialling into the conference.
     */
    public MonoMediaConfPolicy (boolean _joinAllowed) {

        this.joinAllowed = _joinAllowed;
    }

    /**
     * This method returns a joinAllowed.
     * 
     * @return a boolean value
     */
    public boolean getJoinAllowed() {
        return joinAllowed;
    }


    /**
     * This method sets a joinAllowed.
     */ 
    public void setJoinAllowed(boolean joinAllowed) {
        this.joinAllowed = joinAllowed;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof MonoMediaConfPolicy)) {
            return false;
        } 
        MonoMediaConfPolicy monoMediaConfPolicy = (MonoMediaConfPolicy) o;
        if(!(this.joinAllowed == monoMediaConfPolicy.joinAllowed)) {
            return false;
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // MonoMediaConfPolicy

