//Source file: MultiMediaConfPolicy.java
//Date: October 2006
//Conference Call Control for 3GPP TS 29.198-04-5 V1.0.0 (Release 7)

package org.csapi.jr.se.cc.cccs;

/**
 * Sequence of items for multi-media conferences.
 * 
 */
public final class MultiMediaConfPolicy implements java.io.Serializable {

    private boolean joinAllowed;
    private int mediaAllowed;
    private boolean chaired;
    private org.csapi.jr.se.cc.cccs.VideoHandlingType videoHandling;

    /**
     * Creates a new MultiMediaConfPolicy instance.
     */
    public MultiMediaConfPolicy () {}

    /**
     * Creates a new MultiMediaConfPolicy instance.
     * @param _joinAllowed   Specifies if dial-in to the conference is allowed. Parties can dial-in to the conference using the address returned during reservation. If this is specified the application will receive partyJoined for each participant dialling into the conference.
     * @param _mediaAllowed   Specifies the media that are allowed to be used by the participants. For example this can be used to limit the conference to audio only, even when all participants support video.
     * @param _chaired   Specifies whether the conference is chaired or free. In a chaired conference the application or one of the participants acting as chair has special privileges; for example can control the video distribution.
     * @param _videoHandling   Specifies how the video should be handled.
     */
    public MultiMediaConfPolicy (boolean _joinAllowed, int _mediaAllowed, boolean _chaired, org.csapi.jr.se.cc.cccs.VideoHandlingType _videoHandling) {

        this.joinAllowed = _joinAllowed;
        this.mediaAllowed = _mediaAllowed;
        this.chaired = _chaired;
        this.videoHandling = _videoHandling;
    }

    /**
     * This method returns a joinAllowed.
     * 
     * @return a boolean value
     */
    public boolean getJoinAllowed() {
        return joinAllowed;
    }

    /**
     * This method returns a mediaAllowed.
     * 
     * @return a int value
     */
    public int getMediaAllowed() {
        return mediaAllowed;
    }

    /**
     * This method returns a chaired.
     * 
     * @return a boolean value
     */
    public boolean getChaired() {
        return chaired;
    }

    /**
     * This method returns a videoHandling.
     * 
     * @return a org.csapi.jr.se.cc.cccs.VideoHandlingType value
     */
    public org.csapi.jr.se.cc.cccs.VideoHandlingType getVideoHandling() {
        return videoHandling;
    }


    /**
     * This method sets a joinAllowed.
     */ 
    public void setJoinAllowed(boolean joinAllowed) {
        this.joinAllowed = joinAllowed;
    }

    /**
     * This method sets a mediaAllowed.
     */ 
    public void setMediaAllowed(int mediaAllowed) {
        this.mediaAllowed = mediaAllowed;
    }

    /**
     * This method sets a chaired.
     */ 
    public void setChaired(boolean chaired) {
        this.chaired = chaired;
    }

    /**
     * This method sets a videoHandling.
     */ 
    public void setVideoHandling(org.csapi.jr.se.cc.cccs.VideoHandlingType videoHandling) {
        this.videoHandling = videoHandling;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof MultiMediaConfPolicy)) {
            return false;
        } 
        MultiMediaConfPolicy multiMediaConfPolicy = (MultiMediaConfPolicy) o;
        if(!(this.joinAllowed == multiMediaConfPolicy.joinAllowed)) {
            return false;
        }
        if(!(this.mediaAllowed == multiMediaConfPolicy.mediaAllowed))  {
            return false;
        }
        if(!(this.chaired == multiMediaConfPolicy.chaired)) {
            return false;
        }
        if ((this.videoHandling != null) && (multiMediaConfPolicy.videoHandling != null)) {
            if(!(this.videoHandling.equals(multiMediaConfPolicy.videoHandling))) {
                return false;
            }
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // MultiMediaConfPolicy

