//Source file: SubConfCall.java
//Date: October 2006
//Conference Call Control for 3GPP TS 29.198-04-5 V1.0.0 (Release 7)

package org.csapi.jr.se.cc.cccs;

/**
 * This interface represents a SubConfCall.<BR>
 *
 */
public interface SubConfCall extends org.csapi.jr.se.Service {

    /**
     * Adds a SubConfCallListener which is interested in events generated by the SubConfCall.
     *
     * @param  subConfCallListener  A reference to the SubConfCallListener which is to be added as
     *         a listener.
     */
    void addSubConfCallListener(org.csapi.jr.se.cc.cccs.SubConfCallListener subConfCallListener);

    /**
     * Removes a SubConfCallListener which is no longer interested in events generated by the SubConfCall.
     *
     * @param  subConfCallListener  A reference to the SubConfCallListener which is to be removed as
     *         a listener.
     */
    void removeSubConfCallListener(org.csapi.jr.se.cc.cccs.SubConfCallListener subConfCallListener);

    /**
     * Returns a reference to the ConfCall responsible for creation of the SubConfCall.
     *
     * @return  A reference to the ConfCall responsible for creation of the SubConfCall.
     */
    org.csapi.jr.se.cc.cccs.ConfCall getConfCall();

    /**
     * Invokes the mergeSubConference() method on the Parlay Gateway.
     */
    void mergeSubConference(
     org.csapi.jr.se.cc.cccs.SubConfCall targetSubConference)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException;

    /**
     * Invokes the moveCallLeg() method on the Parlay Gateway.
     */
    void moveCallLeg(
     org.csapi.jr.se.cc.cccs.SubConfCall targetSubConference,
     org.csapi.jr.se.cc.mpccs.CallLeg callLeg)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException;

    /**
     * Invokes the inspectVideo() method on the Parlay Gateway.
     */
    void inspectVideo(
     org.csapi.jr.se.cc.mpccs.CallLeg inspectedCallLeg)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException;

    /**
     * Invokes the inspectVideoCancel() method on the Parlay Gateway.
     */
    void inspectVideoCancel()
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException;

    /**
     * Invokes the appointSpeaker() method on the Parlay Gateway.
     */
    void appointSpeaker(
     org.csapi.jr.se.cc.mpccs.CallLeg speakerCallLeg)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException;

    /**
     * Invokes the chairSelection() method on the Parlay Gateway.
     */
    void chairSelection(
     org.csapi.jr.se.cc.mpccs.CallLeg chairCallLeg)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException;

    /**
     * Invokes the changeConferencePolicy() method on the Parlay Gateway.
     */
    void changeConferencePolicy(
           org.csapi.jr.se.cc.cccs.ConfPolicy conferencePolicy)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException;

    /**
     * Invokes the splitSubConference() method on the Parlay Gateway and returns a reference to a transient interface.
     */
    org.csapi.jr.se.cc.cccs.SubConfCall splitSubConference(
           int[]                           callLegList)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException;

}
