//Source file: VideoHandlingType.java
//Date: October 2006
//Conference Call Control for 3GPP TS 29.198-04-5 V1.0.0 (Release 7)

package org.csapi.jr.se.cc.cccs;

/**
 * Defines how video should be handled in the conference.
 *
 */
public final class VideoHandlingType implements java.io.Serializable {

    private int _value;
    private static int _size = 3;
    private static VideoHandlingType[] _array = new VideoHandlingType[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private VideoHandlingType(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Video is switched automatically based on audio output of the speaker
     */
    public static final int _SWITCHED_VIDEO_VOICE_CONTROLLED =  0;

    /**
     * Video is switched automatically based on audio output of the speaker
     */
    public static final VideoHandlingType SWITCHED_VIDEO_VOICE_CONTROLLED = new VideoHandlingType(_SWITCHED_VIDEO_VOICE_CONTROLLED);

    /**
     * Video is switched, chair determines the speaker
     */
    public static final int _SWITCHED_VIDEO_CHAIR_CONTROLLED =  1;

    /**
     * Video is switched, chair determines the speaker
     */
    public static final VideoHandlingType SWITCHED_VIDEO_CHAIR_CONTROLLED = new VideoHandlingType(_SWITCHED_VIDEO_CHAIR_CONTROLLED);

    /**
     * Video is mixed, no special treatment of speaker
     */
    public static final int _MIXED_VIDEO =  2;

    /**
     * Video is mixed, no special treatment of speaker
     */
    public static final VideoHandlingType MIXED_VIDEO = new VideoHandlingType(_MIXED_VIDEO);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved VideoHandlingType object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the VideoHandlingType object
     */
    public String getValueText() {
        switch (_value) {
            case _SWITCHED_VIDEO_VOICE_CONTROLLED:
                return "SWITCHED_VIDEO_VOICE_CONTROLLED";
            case _SWITCHED_VIDEO_CHAIR_CONTROLLED:
                return "SWITCHED_VIDEO_CHAIR_CONTROLLED";
            case _MIXED_VIDEO:
                return "MIXED_VIDEO";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 2
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static VideoHandlingType getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof VideoHandlingType)) {
            return false;
        }
        VideoHandlingType videoHandlingType = (VideoHandlingType) o; 
        if(!(this.getValue() == videoHandlingType.getValue())) {
            return false;
        }
        if (this.hashCode() != videoHandlingType.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // VideoHandlingType

